InvalidDer

Enum InvalidDer 

pub enum InvalidDer {
    Parse(Err<X509Error>),
    ExcessDER,
    InvalidTimestamp(Error),
    CertId(InvalidCertId),
    IssuerCertId(InvalidIssuerCertId),
}
Errors when parsing a DER certificate.

Variants



Parse(Err<X509Error>)

DER bytes provided to a Certificate constructor did not contain a valid X509 certificate.



ExcessDER

After parsing the X509 certificate, there was unparsed data remaining (parser error).



InvalidTimestamp(Error)

Validity in a Certificate is invalid.



CertId(InvalidCertId)

The CertId (Subject Key Identifier) field is missing or has an invalid length in the X509 certificate.

This is allowed by the X509 spec, but it is required as an invariant of our system.



IssuerCertId(InvalidIssuerCertId)

The IssuerCertId (Authority Key Identifier) field is missing or has an invalid length in the X509 certificate.

This is allowed by the X509 spec, but it is required as an invariant of our system.