pub struct Fingerprint { /* private fields */ }Expand description
A Fingerprint is a deterministic, fixed-length SHA-256 hash that
uniquely identifies a single issued Certificate.
The fingerprint is constructed by hashing the (DER encoded) bytes of a
Certificate, a process that is lightly described in RFC 4387  2.2 as
a certHash. Unlike the RFC, we use SHA-256 as the hash instead of SHA-1 (a
common modification for newer systems, including new versions of OpenSSL).
A Fingerprint should be used when checking if two certificates are
identical.
Implementations
Sourceimpl Fingerprint
impl Fingerprint
Sourcepub fn as_hex_str(&self) -> &str
pub fn as_hex_str(&self) -> &str
Render the Fingerprint as a lowercase hex string delimited by
colons in the style of OpenSSL.
Example: cc:cb:0f:63:f1:63:5e:f1:0e:26:e8:82:f7:7a:6e:f9
This value is lazily rendered and cached for reuse.