PublicKey

Struct PublicKey 

pub struct PublicKey<'a>(/* private fields */);
The public portion of a PrivateKey.

Internal Encoding

This key holds the raw DER key material bytes (without algorithm identifier).

Specifically this holds the subjectPublicKey bit string field of the SubjectPublicKeyInfo ASN.1 message as defined in RFC 5280  4.1.

Implementations

Source

impl<'a> PublicKey<'a>

pub fn verify( &self, data: &[u8], sig: &Signature, ) -> Result<(), SignatureVerifyErr>

Verify that this key pair generated sig over data.

pub fn key_id(&self) -> KeyId

Generate a KeyId that uniquely identifies this key, suitable for use as an X509 Subject Key Identifier.